@@ -25,13 +25,10 @@
 #include <Windows.h>
 #endif
 
-constexpr auto APPLICATION_ID = "org.kde.francis";
-
-#include "app.h"
-#include "config.h"
-#include "controller.h"
 #include "version-francis.h"
 
+using namespace Qt::StringLiterals;
+
 Q_DECL_EXPORT int main(int argc, char *argv[])
 {
 #ifdef Q_OS_ANDROID
@@ -75,17 +72,8 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
 
     QQmlApplicationEngine engine;
 
-    auto config = Config::self();
-    qmlRegisterSingletonInstance(APPLICATION_ID, 1, 0, "Config", config);
-
-    App application;
-    qmlRegisterSingletonInstance(APPLICATION_ID, 1, 0, "App", &application);
-
-    Controller controller;
-    qmlRegisterSingletonInstance(APPLICATION_ID, 1, 0, "Controller", &controller);
-
     engine.rootContext()->setContextObject(new KLocalizedContext(&engine));
-    engine.load(QUrl(QStringLiteral("qrc:///main.qml")));
+    engine.loadFromModule(u"org.kde.francis"_s, u"Main"_s);
 
     if (engine.rootObjects().isEmpty()) {
         return -1;
@@ -95,17 +83,5 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
     KDBusService service(KDBusService::Unique);
 #endif
 
-    // Restore window size and position
-    const auto rootObjects = engine.rootObjects();
-    for (auto obj : rootObjects) {
-        auto view = qobject_cast<QQuickWindow *>(obj);
-        if (view) {
-            if (view->isVisible()) {
-                application.restoreWindowGeometry(view);
-            }
-            break;
-        }
-    }
-
     return app.exec();
 }
